@@ -5,6 +5,7 @@ from typing import Final
 from asyncio import TimeoutError as AsyncIOTimeoutError
 from aiohttp import ClientConnectionError, ClientResponseError
 
+from async_reolink.api.errors import ErrorCodes
 
 CONNECTION_ERRORS: Final = (
     TimeoutError,
@@ -16,3 +17,9 @@ CONNECTION_ERRORS: Final = (
 RESPONSE_ERRORS: Final = (
     ClientResponseError
 )
+
+AUTH_ERRORCODES: Final = (
+    ErrorCodes.AUTH_REQUIRED,
+    ErrorCodes.LOGIN_FAILED,
+    ErrorCodes.PASSWORD_WRONG
+)
